@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 // CERTI - HLA RunTime Infrastructure
-// Copyright (C) 2002, 2003, 2004  ONERA
+// Copyright (C) 2002-2005  ONERA
 //
 // This file is part of CERTI
 //
@@ -18,7 +18,7 @@
 // along with this program ; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: FederationsList.cc,v 3.23 2004/01/09 16:29:50 breholee Exp $
+// $Id: FederationsList.cc,v 3.29 2005/04/30 16:41:28 breholee Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -30,22 +30,16 @@ using std::endl ;
 namespace certi {
 namespace rtig {
 
-static pdCDebug D("FEDERATIONSLIST", "(ListFede) - ");
+static PrettyDebug D("FEDERATIONSLIST", __FILE__);
 
 // ----------------------------------------------------------------------------
 // Constructor
-FederationsList::FederationsList(SocketServer *server, AuditFile *audit)
-    : list<Federation *>()
+FederationsList::FederationsList(SocketServer &server, AuditFile &audit)
+    : list<Federation *>(),
+      socketServer(server),
+      auditFile(audit),
+      verbose(false)
 {
-    if (server == NULL)
-        throw RTIinternalError("FederationsList: No SocketServer was given.");
-
-    if (audit == NULL)
-        throw RTIinternalError("FederationsList: No AuditServer was given.");
-
-    socketServer = server ;
-    auditFile = audit ;
-    verbose = false ;
 }
 
 // ----------------------------------------------------------------------------
@@ -159,14 +153,14 @@ void FederationsList::createFederation(const char *name,
 
     // It may throw RTIinternalError
     checkHandle(handle);
-    auditFile->addToLinef(", Handle : %hu", handle);
+    auditFile << ", Handle : " << (long) handle ;
     if (name == NULL) throw RTIinternalError("Invalid Federation Name.");
 
     // It should throw FederationExecutionDoesNotExist.
     try {
         exists(name, unused);
         D.Out(pdExcept, "Federation %s already present.", name);
-        throw FederationExecutionAlreadyExists();
+        throw FederationExecutionAlreadyExists("");
     }
     catch (FederationExecutionDoesNotExist &e) {
         D.Out(pdDebug,
@@ -261,7 +255,7 @@ FederationsList::exists(const char *name,
     }
 
     D.Out(pdDebug, "EstPresent throws FederationExecutionDoesNotExist.");
-    throw FederationExecutionDoesNotExist();
+    throw FederationExecutionDoesNotExist("");
 }
 
 // ----------------------------------------------------------------------------
@@ -407,6 +401,7 @@ FederationsList::updateParameter(Handle handle,
                                  ParameterValue *values,
                                  UShort list_size,
                                  FederationTime time,
+				 RegionHandle region,
                                  const char *tag)
     throw (FederateNotExecutionMember,
            FederateNotPublishing,
@@ -427,7 +422,7 @@ FederationsList::updateParameter(Handle handle,
     searchFederation(handle, federation);
 
     federation->broadcastInteraction(federate, interaction, parameters, values,
-                                     list_size, time, tag);
+                                     list_size, time, region, tag);
 }
 
 // ----------------------------------------------------------------------------
@@ -572,8 +567,7 @@ FederationsList::subscribeObject(Handle handle,
                                  FederateHandle federate,
                                  ObjectClassHandle object_class,
                                  AttributeHandle *attributes,
-                                 UShort list_size,
-                                 bool sub)
+                                 UShort list_size)
     throw (ObjectClassNotDefined,
            AttributeNotDefined,
            FederationExecutionDoesNotExist,
@@ -592,8 +586,7 @@ FederationsList::subscribeObject(Handle handle,
     // It may throw FederationExecutionDoesNotExist.
     searchFederation(handle, federation);
 
-    federation->subscribeObject(federate, object_class, attributes, list_size,
-                                sub);
+    federation->subscribeObject(federate, object_class, attributes, list_size);
 }
 
 // ----------------------------------------------------------------------------
@@ -1055,14 +1048,16 @@ FederationsList::associateRegion(Handle federation,
 	throw (RegionInUse, FederateNotExecutionMember, SaveInProgress,
 	       RestoreInProgress, RTIinternalError)
 {
+    D[pdDebug] << "Associate region " << region << " for updates." << endl ;
+    D[pdDebug] << "F:" << federation << ", F:" << federate << endl ;
+
     Federation *f = 0 ;
 
     searchFederation(federation, f);
+
     checkHandle(federation);
     checkHandle(federate);
 
-    D[pdDebug] << "Associate region for updates " << region << endl ;
-
     f->associateRegion(federate, object, region, nb_attributes, attributes);
 }
 
@@ -1168,6 +1163,30 @@ FederationsList::unsubscribeInteractionWR(Handle federation,
     f->unsubscribeInteractionWR(federate, ic, region);
 }
 
+// ----------------------------------------------------------------------------
+// registerObjectWithRegion
+ObjectHandle FederationsList::registerObjectWithRegion(Handle federation,
+						       FederateHandle federate, 
+						       ObjectClassHandle handle,
+						       ObjectName tag,
+						       RegionHandle region,
+						       int nb,
+						       AttributeHandle *attrs)
+	throw (ObjectClassNotDefined, ObjectClassNotPublished,
+	       AttributeNotDefined, AttributeNotPublished, RegionNotKnown,
+	       InvalidRegionContext, ObjectAlreadyRegistered,
+	       FederateNotExecutionMember, SaveInProgress, RestoreInProgress,
+	       RTIinternalError)
+{
+    Federation *f = 0 ;
+
+    searchFederation(federation, f);
+    checkHandle(federation);
+    checkHandle(federate);
+
+    return f->registerObjectWithRegion(federate, handle, tag, region, nb, attrs);
+}
+
 // ----------------------------------------------------------------------------
 void
 FederationsList::requestFederationSave(Handle the_federation,
@@ -1245,5 +1264,5 @@ FederationsList::federateRestoreStatus(Handle the_federation,
 
 }} // certi::rtig
 
-// EOF $Id: FederationsList.cc,v 3.23 2004/01/09 16:29:50 breholee Exp $
+// EOF $Id: FederationsList.cc,v 3.29 2005/04/30 16:41:28 breholee Exp $
 
