@@ -1,25 +1,20 @@
 // ----------------------------------------------------------------------------
 // CERTI - HLA RunTime Infrastructure
-// Copyright (C) 2002, 2003  ONERA
+// Copyright (C) 2002-2005  ONERA
 //
-// This file is part of CERTI-libCERTI
-//
-// CERTI-libCERTI is free software ; you can redistribute it and/or
+// This program is free software ; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License
 // as published by the Free Software Foundation ; either version 2 of
 // the License, or (at your option) any later version.
 //
-// CERTI-libCERTI is distributed in the hope that it will be useful, but
+// This program is distributed in the hope that it will be useful, but
 // WITHOUT ANY WARRANTY ; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public
 // License along with this program ; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA
-//
-// $Id: GAV_aux.cc,v 3.11 2004/03/04 20:19:05 breholee Exp $
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -33,6 +28,8 @@
 
 using std::list ;
 
+using namespace certi ;
+
 // ----------------------------------------------------------------------------
 // AttributeHandleValuePair
 // ----------------------------------------------------------------------------
@@ -47,14 +44,14 @@ AttributeHandleValuePair::AttributeHandleValuePair(Handle handle,
     _handle = handle ;
     _valueLength = value_length ;
 
-    _value = (char *)malloc(value_length);
+    _value = new char[value_length];
     memcpy(_value, value, value_length);
 }
 
 // ----------------------------------------------------------------------------
 AttributeHandleValuePair::~AttributeHandleValuePair()
 {
-    delete _value ;
+    delete[] _value ;
 }
 
 // ----------------------------------------------------------------------------
@@ -83,7 +80,7 @@ AttributeHandleValuePairSetImp::getHandle(ULong i) const
             return (*j)->_handle ;
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
@@ -97,7 +94,7 @@ AttributeHandleValuePairSetImp::getValueLength(ULong i) const
             return (*j)->_valueLength ;
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
@@ -116,7 +113,7 @@ AttributeHandleValuePairSetImp::getValue(ULong i,
         }
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
@@ -133,19 +130,19 @@ AttributeHandleValuePairSetImp::getValuePointer(ULong i,
         }
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
-inline TransportType
+TransportType
 AttributeHandleValuePairSetImp::getTransportType(ULong) const
-    throw (ArrayIndexOutOfBounds, InvalidHandleValuePairSetContext)
+    throw (RTI::InvalidHandleValuePairSetContext)
 {
     return _transport ;
 }
 
 // ----------------------------------------------------------------------------
-inline OrderType
+OrderType
 AttributeHandleValuePairSetImp::getOrderType(ULong) const
     throw (ArrayIndexOutOfBounds, InvalidHandleValuePairSetContext)
 {
@@ -153,12 +150,11 @@ AttributeHandleValuePairSetImp::getOrderType(ULong) const
 }
 
 // ----------------------------------------------------------------------------
-Region*
+RTI::Region *
 AttributeHandleValuePairSetImp::getRegion(ULong) const
-    throw (ArrayIndexOutOfBounds, InvalidHandleValuePairSetContext,
-           UnimplementedService)//CERTI
+    throw (ArrayIndexOutOfBounds, InvalidHandleValuePairSetContext)
 {
-    throw UnimplementedService();
+    throw RTIinternalError("Unimplemented service");
 }
 
 // ----------------------------------------------------------------------------
@@ -188,17 +184,16 @@ AttributeHandleValuePairSetImp::remove(Handle h)
         }
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
 void
 AttributeHandleValuePairSetImp::moveFrom(const AttributeHandleValuePairSet&,
                                          ULong&)
-    throw (ValueCountExceeded, ArrayIndexOutOfBounds,
-           UnimplementedService) //CERTI
+    throw (ValueCountExceeded, ArrayIndexOutOfBounds)
 {
-    throw UnimplementedService();
+    throw RTIinternalError("Unimplemented service");
 }
 
 // ----------------------------------------------------------------------------
@@ -239,8 +234,8 @@ AttributeHandleValuePairSetImp::next(ULong) const
 // AttributeSetFactory
 // ----------------------------------------------------------------------------
 
-AttributeHandleValuePairSet*
-AttributeSetFactory::create(ULong)
+RTI::AttributeHandleValuePairSet *
+RTI::AttributeSetFactory::create(ULong)
     throw (MemoryExhausted, ValueCountExceeded, HandleValuePairMaximumExceeded)
 {
     AttributeHandleValuePairSetImp *ahvps ;
@@ -277,7 +272,7 @@ AttributeHandleSetImp::getHandle(ULong i) const
             return (*h);
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
@@ -293,10 +288,10 @@ void
 AttributeHandleSetImp::remove(AttributeHandle h)
     throw (AttributeNotDefined)// not guaranteed safe while iterating
 {
-    if (isMember(h) == RTI_TRUE)
+    if (isMember(h) == RTI::RTI_TRUE)
         list<AttributeHandle>::remove(h);
     else
-        throw AttributeNotDefined();
+        throw AttributeNotDefined("");
 }
 
 // ----------------------------------------------------------------------------
@@ -307,33 +302,28 @@ AttributeHandleSetImp::empty()
 }
 
 // ----------------------------------------------------------------------------
-inline Boolean
+RTI::Boolean
 AttributeHandleSetImp::isEmpty() const
 {
-    return ((list<AttributeHandle>::empty()) ? RTI_TRUE : RTI_FALSE);
+    return RTI::Boolean(list<AttributeHandle>::empty());
 }
 
 // ----------------------------------------------------------------------------
-Boolean
+RTI::Boolean
 AttributeHandleSetImp::isMember(AttributeHandle h) const
 {
-    list<AttributeHandle>::const_iterator result = find(begin(), end(), h);
-
-    if (result == end())
-        return RTI_FALSE ;
-    else
-        return RTI_TRUE ;
+    return RTI::Boolean(find(begin(), end(), h) != end());
 }
 
 // ----------------------------------------------------------------------------
 // AttributeHandleSetImpFactory
 // ----------------------------------------------------------------------------
 
-AttributeHandleSet*
-AttributeHandleSetFactory::create(ULong)
+RTI::AttributeHandleSet *
+RTI::AttributeHandleSetFactory::create(ULong)
     throw (MemoryExhausted, ValueCountExceeded)
 {
-    return ((AttributeHandleSet *)new AttributeHandleSetImp());
+    return new AttributeHandleSetImp();
 }
 
 // ----------------------------------------------------------------------------
@@ -363,7 +353,7 @@ FederateHandleSetImp::getHandle(ULong i) const
             return (*h);
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
@@ -377,12 +367,12 @@ FederateHandleSetImp::add(FederateHandle h)
 // ----------------------------------------------------------------------------
 void
 FederateHandleSetImp::remove(FederateHandle h)
-    throw (AttributeNotDefined, ArrayIndexOutOfBounds)
+    throw (ArrayIndexOutOfBounds)
 {
-    if (isMember(h) == RTI_TRUE)
+    if (isMember(h) == RTI::RTI_TRUE)
         list<FederateHandle>::remove(h);
     else
-        throw AttributeNotDefined();
+        throw AttributeNotDefined("");
 }
 
 // ----------------------------------------------------------------------------
@@ -393,23 +383,18 @@ FederateHandleSetImp::empty()
 }
 
 // ----------------------------------------------------------------------------
-Boolean
+RTI::Boolean
 FederateHandleSetImp::isMember(FederateHandle h) const
 {
-    list<FederateHandle>::const_iterator result = find(begin(), end(), h);
-
-    if (result == end())
-        return RTI_FALSE ;
-    else
-        return RTI_TRUE ;
+    return RTI::Boolean(find(begin(), end(), h) != end());
 }
 
 // ----------------------------------------------------------------------------
 // FederateHandleSetFactory
 // ----------------------------------------------------------------------------
 
-FederateHandleSet*
-FederateHandleSetFactory::create(ULong)
+RTI::FederateHandleSet *
+RTI::FederateHandleSetFactory::create(ULong)
     throw (MemoryExhausted, ValueCountExceeded)
 {
     return ((FederateHandleSet *) new FederateHandleSetImp());
@@ -426,14 +411,14 @@ ParameterHandleValuePair::ParameterHandleValuePair(Handle handle,
     _handle = handle ;
     _valueLength = value_length ;
 
-    _value = (char *)malloc(value_length);
+    _value = (char *) malloc(value_length);
     memcpy(_value, value, value_length);
 }
 
 // ----------------------------------------------------------------------------
 ParameterHandleValuePair::~ParameterHandleValuePair()
 {
-    delete _value ;
+    free(_value);
 }
 
 // ----------------------------------------------------------------------------
@@ -451,7 +436,7 @@ ParameterHandleValuePairSetImp::~ParameterHandleValuePairSetImp()
 }
 
 // ----------------------------------------------------------------------------
-inline ULong
+ULong
 ParameterHandleValuePairSetImp::size() const
 {
     return list<ParameterHandleValuePair *>::size();
@@ -468,7 +453,7 @@ ParameterHandleValuePairSetImp::getHandle(ULong i) const
             return (*j)->_handle ;
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
@@ -482,7 +467,7 @@ ParameterHandleValuePairSetImp::getValueLength(ULong i) const
             return (*j)->_valueLength ;
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
@@ -501,7 +486,7 @@ ParameterHandleValuePairSetImp::getValue(ULong i,
         }
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
@@ -518,7 +503,7 @@ ParameterHandleValuePairSetImp::getValuePointer(ULong i,
         }
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
@@ -538,12 +523,11 @@ ParameterHandleValuePairSetImp::getOrderType() const
 }
 
 // ----------------------------------------------------------------------------
-Region *
+RTI::Region *
 ParameterHandleValuePairSetImp::getRegion() const
-    throw (InvalidHandleValuePairSetContext,
-           UnimplementedService)//CERTI
+    throw (InvalidHandleValuePairSetContext)
 {
-    throw UnimplementedService();
+    throw RTIinternalError("Unimplemented service");
 }
 
 // ----------------------------------------------------------------------------
@@ -573,17 +557,16 @@ ParameterHandleValuePairSetImp::remove(Handle h)
         }
     }
 
-    throw ArrayIndexOutOfBounds();
+    throw ArrayIndexOutOfBounds("");
 }
 
 // ----------------------------------------------------------------------------
 void
 ParameterHandleValuePairSetImp::moveFrom(const ParameterHandleValuePairSet&,
                                          ULong&)
-    throw (ValueCountExceeded, ArrayIndexOutOfBounds,
-           UnimplementedService)//CERTI
+    throw (ValueCountExceeded, ArrayIndexOutOfBounds)
 {
-    throw UnimplementedService();
+    throw RTIinternalError("Unimplemented service");
 }
 
 // ----------------------------------------------------------------------------
@@ -624,10 +607,9 @@ ParameterHandleValuePairSetImp::next(ULong) const
 // ParameterSetFactory
 // ----------------------------------------------------------------------------
 
-ParameterHandleValuePairSet*
-ParameterSetFactory::create(ULong size)
-    throw (MemoryExhausted, ValueCountExceeded,
-           HandleValuePairMaximumExceeded)
+RTI::ParameterHandleValuePairSet *
+RTI::ParameterSetFactory::create(ULong size)
+    throw (MemoryExhausted, ValueCountExceeded, HandleValuePairMaximumExceeded)
 {
     ParameterHandleValuePairSetImp *phvps ;
     phvps = new ParameterHandleValuePairSetImp(size);
@@ -638,5 +620,3 @@ ParameterSetFactory::create(ULong size)
 }
 
 } // namespace certi
-
-// $Id: GAV_aux.cc,v 3.11 2004/03/04 20:19:05 breholee Exp $
