@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 // CERTI - HLA RunTime Infrastructure
-// Copyright (C) 2002, 2003  ONERA
+// Copyright (C) 2002-2005  ONERA
 //
 // This file is part of CERTI-libCERTI
 //
@@ -19,7 +19,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: InteractionSet.cc,v 3.10 2003/10/27 10:12:07 breholee Exp $
+// $Id: InteractionSet.cc,v 3.13 2005/04/30 16:52:44 breholee Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -63,6 +63,7 @@ InteractionSet::broadcastInteraction(FederateHandle federate_handle,
                                      ParameterValue *value_list,
                                      UShort list_size,
                                      FederationTime the_time,
+				     const RTIRegion *region,
                                      const char *the_tag)
     throw (FederateNotPublishing,
            InteractionClassNotDefined,
@@ -79,6 +80,7 @@ InteractionSet::broadcastInteraction(FederateHandle federate_handle,
                                              value_list,
                                              list_size,
                                              the_time,
+					     region,
                                              the_tag);
 
     // Pass the Message(and its BroadcastList) to the Parent Classes.
@@ -162,7 +164,7 @@ InteractionSet::getByHandle(InteractionClassHandle the_handle)
             return (*i);
     }
 
-    throw InteractionClassNotDefined();
+    throw InteractionClassNotDefined("");
 }
 
 // ----------------------------------------------------------------------------
@@ -172,7 +174,7 @@ InteractionSet::getInteractionClassHandle(const char *the_name)
     throw (NameNotFound, RTIinternalError)
 {
     if (the_name == NULL)
-        throw RTIinternalError();
+        throw RTIinternalError("");
 
     list<Interaction *>::const_iterator i ;
     for (i = begin(); i != end(); i++) {
@@ -180,7 +182,7 @@ InteractionSet::getInteractionClassHandle(const char *the_name)
             return (*i)->getHandle();
     }
 
-    throw NameNotFound();
+    throw NameNotFound("");
 }
 
 // ----------------------------------------------------------------------------
@@ -195,7 +197,7 @@ InteractionSet::getInteractionClassName(InteractionClassHandle the_handle)
             return (*i)->getName();
     }
 
-    throw InteractionClassNotDefined();
+    throw InteractionClassNotDefined("");
 }
 
 // ----------------------------------------------------------------------------
@@ -208,7 +210,7 @@ InteractionSet::getParameterHandle(const char *the_name,
            RTIinternalError)
 {
     if (the_name == NULL)
-        throw RTIinternalError();
+        throw RTIinternalError("");
 
     // It may throw InteractionClassNotDefined
     Interaction *interaction = getByHandle(the_class);
@@ -284,6 +286,7 @@ InteractionSet::publish(FederateHandle federate_handle,
 void
 InteractionSet::subscribe(FederateHandle federate_handle,
                           InteractionClassHandle interaction_handle,
+			  const RTIRegion *region,
                           bool subscribe)
     throw (FederateNotSubscribing,
            InteractionClassNotDefined,
@@ -293,11 +296,11 @@ InteractionSet::subscribe(FederateHandle federate_handle,
     // It may throw InteractionClassNotDefined
     Interaction *interaction = getByHandle(interaction_handle);
     if (subscribe)
-	interaction->subscribe(federate_handle);
+	interaction->subscribe(federate_handle, region);
     else
-	interaction->unsubscribe(federate_handle);
+	interaction->unsubscribe(federate_handle, region);
 }
 
 } // namespace certi
 
-// $Id: InteractionSet.cc,v 3.10 2003/10/27 10:12:07 breholee Exp $
+// $Id: InteractionSet.cc,v 3.13 2005/04/30 16:52:44 breholee Exp $
