@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 // CERTI - HLA RunTime Infrastructure
-// Copyright (C) 2002, 2003  ONERA
+// Copyright (C) 2002-2005  ONERA
 //
 // This file is part of CERTI-libCERTI
 //
@@ -19,13 +19,14 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: ObjectClassAttribute.cc,v 3.17 2003/10/27 10:15:12 breholee Exp $
+// $Id: ObjectClassAttribute.cc,v 3.23 2005/04/09 15:17:31 breholee Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
 #include "ObjectClassAttribute.hh"
 
 #include "PrettyDebug.hh"
+#include "helper.hh"
 
 #include <iostream>
 #include <list>
@@ -39,22 +40,6 @@ namespace certi {
 
 static pdCDebug D("OBJECTCLASSATTRIBUTE", "(Obj.Cl.Attr) ");
 
-// ----------------------------------------------------------------------------
-/*! Throw SecurityError if the Federate is not allowed to access the Object
-  Class, and print an Audit message containing Reason.
-*/
-void
-ObjectClassAttribute::checkFederateAccess(FederateHandle fed,
-					  const char *reason)
-    throw (SecurityError)
-{
-    if (server && !server->canFederateAccessData(fed, level)) {
-        cout << "Attribute " << handle << " : SecurityError for federate "
-             << fed << '(' << reason << ")." << endl ;
-        throw SecurityError("Federate should not access ObjectClassAttribute.");
-    }
-}
-
 // ----------------------------------------------------------------------------
 //! No parameters constructor.
 /*! This constructor initialize the attribute with default parameters.
@@ -82,30 +67,24 @@ ObjectClassAttribute::ObjectClassAttribute(ObjectClassAttribute *source)
 }
 
 // ----------------------------------------------------------------------------
-//! Destructor (Empty private Lists, and free Name memory)
+//! Destructor
 ObjectClassAttribute::~ObjectClassAttribute()
 {
-    // Deleting Publishers
-    if (!publishers.empty())
-        D[pdError] << "Attribute " << handle
-		   << ": Publishers list not empty at termination." << endl ;
+}
 
-    list<Publisher *>::iterator p ;
-    for (p = publishers.begin(); p != publishers.end(); p++) {
-        delete (*p);
+// ----------------------------------------------------------------------------
+/*! Throw SecurityError if the Federate is not allowed to access the Object
+  Class, and print an Audit message containing Reason.
+*/
+void
+ObjectClassAttribute::checkFederateAccess(FederateHandle fed,
+					  const char *reason) const
+{
+    if (server && !server->canFederateAccessData(fed, level)) {
+        cout << "Attribute " << handle << " : SecurityError for federate "
+             << fed << '(' << reason << ")." << endl ;
+        throw SecurityError("Federate should not access ObjectClassAttribute.");
     }
-    publishers.clear();
-
-    // Deleting Subscribers
-    if (!subscribers.empty())
-        D[pdError] << "Attribute " << handle
-		   << ": Subscribers list not empty at termination." << endl ;
-
-    list<Subscriber *>::iterator s ;
-    for (s = subscribers.begin(); s != subscribers.end(); s++) {
-        delete (*s);
-    }
-    subscribers.clear();
 }
 
 // ----------------------------------------------------------------------------
@@ -113,29 +92,9 @@ ObjectClassAttribute::~ObjectClassAttribute()
 void
 ObjectClassAttribute::deletePublisher(FederateHandle fed)
 {
-    list<Publisher *>::iterator i ;
-    for (i = publishers.begin(); i != publishers.end(); ++i) {
-	if ((*i)->getHandle() == fed) {
-            delete *i ;
-            publishers.erase(i);
-            return ;
-        }
-    }
-}
-
-// ----------------------------------------------------------------------------
-//! Removes a subscribed federate
-void
-ObjectClassAttribute::deleteSubscriber(FederateHandle fed, RegionImp *region)
-{
-    list<Subscriber *>::iterator i ;
-    for (i = subscribers.begin(); i != subscribers.end(); ++i) {
-	if ((*i)->match(fed, region)) {
-            delete *i ;
-            subscribers.erase(i);
-            return ;
-        }
-    }
+    PublishersList::iterator it = publishers.find(fed);
+    if (it != publishers.end())
+	publishers.erase(it);
 }
 
 // ----------------------------------------------------------------------------
@@ -158,33 +117,7 @@ ObjectClassAttribute::display() const
 bool
 ObjectClassAttribute::isPublishing(FederateHandle fed) const
 {
-    list<Publisher *>::const_iterator i = publishers.begin();
-    for (i = publishers.begin(); i != publishers.end(); i++) {
-        if ((*i)->getHandle() == fed)
-            return true ;
-    }
-    return false ;
-}
-
-// ----------------------------------------------------------------------------
-//! Returns true if federate has subscribed to this attribute
-bool
-ObjectClassAttribute::hasSubscribed(FederateHandle fed, RegionImp *region) const
-{
-    list<Subscriber *>::const_iterator i ;
-    for (i = subscribers.begin(); i != subscribers.end(); ++i) {
-        if ((*i)->match(fed, region))
-            return true ;
-    }
-    return false ;
-}
-
-// ----------------------------------------------------------------------------
-//! Returns true if federate has subscribed to this attribute
-bool
-ObjectClassAttribute::hasSubscribed(FederateHandle fed) const
-{
-    return hasSubscribed(fed, 0);
+    return publishers.find(fed) != publishers.end();
 }
 
 // ----------------------------------------------------------------------------
@@ -197,7 +130,7 @@ ObjectClassAttribute::publish(FederateHandle fed)
         checkFederateAccess(fed, "Publish");
         D[pdInit] << "Attribute " << handle << ": Added Federate " << fed
 		  << " to publishers list." << endl ;
-	publishers.push_front(new Publisher(fed));
+	publishers.insert(fed);
     }
     else
         D[pdError] << "Attribute " << handle
@@ -259,84 +192,22 @@ ObjectClassAttribute::getSpace() const
     return space ;
 }
 
-// ----------------------------------------------------------------------------
-//! unsubscribe
-void
-ObjectClassAttribute::unsubscribe(FederateHandle fed, RegionImp *region)
-    throw (RTIinternalError)
-{
-    if (hasSubscribed(fed, region)) {
-        deleteSubscriber(fed, region);
-        D[pdTerm] << "Attribute " << handle << ": Removed Federate "
-		  << fed << " from subscribers list." << endl ;
-    }
-    else {
-        D[pdError] << "Attribute " << handle << ": Unconsistent unsubscribe "
-		   << "request from federate " << fed << endl ;
-    }
-}
-
-// ----------------------------------------------------------------------------
-//! unsubscribe
-void
-ObjectClassAttribute::unsubscribe(FederateHandle fed)
-    throw (RTIinternalError)
-{
-    unsubscribe(fed, 0);
-}
-
-// ----------------------------------------------------------------------------
-//! subscribe
-void
-ObjectClassAttribute::subscribe(FederateHandle fed, RegionImp *region)
-    throw (RTIinternalError, SecurityError)
-{
-    if (!hasSubscribed(fed, region)) {
-        checkFederateAccess(fed, "Subscribe");
-
-	Subscriber *sub = new Subscriber(fed, region);
-	if (region) {
-	    subscribers.push_back(sub);
-	}
-	else {
-	    subscribers.push_front(sub);
-	}
-	
-        D[pdInit] << "Attribute " << handle << ": Added Federate " << fed
-		  << " to subscribers list." << endl ;
-    }
-    else
-        D[pdError] << "Attribute " << handle
-		   << ": Unconsistent subscribe request from federate "
-		   << fed << endl ;
-}
-
-// ----------------------------------------------------------------------------
-//! subscribe
-void
-ObjectClassAttribute::subscribe(FederateHandle fed)
-    throw (RTIinternalError, SecurityError)
-{
-    subscribe(fed, 0);
-}
 
 // ----------------------------------------------------------------------------
 //! Add all attribute's subscribers to the broadcast list
 void
-ObjectClassAttribute::updateBroadcastList(ObjectClassBroadcastList *ocblist)
+ObjectClassAttribute::updateBroadcastList(ObjectClassBroadcastList *ocblist,
+					  const RTIRegion *region)
 {
     switch(ocblist->message->type) {
 
       case NetworkMessage::REFLECT_ATTRIBUTE_VALUES: {
-          list<Subscriber *>::iterator i ;
-          for (i = subscribers.begin(); i != subscribers.end(); i++) {
-              ocblist->addFederate((*i)->getHandle(), handle);
-          }
+	  addFederatesIfOverlap(*ocblist, region, handle);
       } break ;
       case NetworkMessage::REQUEST_ATTRIBUTE_OWNERSHIP_ASSUMPTION: {
-          list<Publisher *>::iterator i ;
+          PublishersList::iterator i ;
           for (i = publishers.begin(); i != publishers.end(); i++) {
-              ocblist->addFederate((*i)->getHandle(), handle);
+              ocblist->addFederate(*i, handle);
           }
       } break ;
       
@@ -346,4 +217,4 @@ ObjectClassAttribute::updateBroadcastList(ObjectClassBroadcastList *ocblist)
 
 } // namespace
 
-// $Id: ObjectClassAttribute.cc,v 3.17 2003/10/27 10:15:12 breholee Exp $
+// $Id: ObjectClassAttribute.cc,v 3.23 2005/04/09 15:17:31 breholee Exp $
