@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 // CERTI - HLA RunTime Infrastructure
-// Copyright (C) 2002, 2003  ONERA
+// Copyright (C) 2002-2005  ONERA
 //
 // This file is part of CERTI-libCERTI
 //
@@ -19,7 +19,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA
 //
-// $Id: SecurityServer.cc,v 3.7 2003/10/27 10:18:56 breholee Exp $
+// $Id: SecurityServer.cc,v 3.9 2005/04/30 17:32:27 breholee Exp $
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -43,15 +43,15 @@ Socket*
 SecurityServer::getSocketLink(FederateHandle theFederate,
                               TransportType theType) const
 {
-    return RTIG_SocketServer->getSocketLink(MyFederation, theFederate, theType);
+    return RTIG_SocketServer.getSocketLink(myFederation, theFederate, theType);
 }
 
 // ----------------------------------------------------------------------------
 //! Compares two security level ID.
-Boolean
+bool
 SecurityServer::dominates(SecurityLevelID A, SecurityLevelID B) const
 {
-    return ((A == B) || (B == PublicLevelID)) ? RTI_TRUE : RTI_FALSE ;
+    return A == B || B == PublicLevelID ;
 }
 
 // ----------------------------------------------------------------------------
@@ -61,7 +61,7 @@ SecurityServer::dominates(SecurityLevelID A, SecurityLevelID B) const
   3- If yes, retrieve federate principal name.
   4- Retrieve Federate level
 */
-Boolean
+bool
 SecurityServer::canFederateAccessData(FederateHandle theFederate,
                                       SecurityLevelID theDataLevelID)
 {
@@ -102,17 +102,16 @@ SecurityServer::canFederateAccessData(FederateHandle theFederate,
 
 // ----------------------------------------------------------------------------
 //! SecurityServer constructor.
-SecurityServer::SecurityServer(SocketServer *theRTIGServer,
-                               AuditFile *theAuditServer,
+SecurityServer::SecurityServer(SocketServer &theRTIGServer,
+                               AuditFile &theAuditServer,
                                Handle theFederation)
-    : list<SecurityLevel *>()
+    :  list<SecurityLevel *>(), audit(theAuditServer),
+       RTIG_SocketServer(theRTIGServer)
 {
-    MyFederation = theFederation ;
-    RTIG_SocketServer = theRTIGServer ;
-    Audit = theAuditServer ;
+    myFederation = theFederation ;
 
-    if ((MyFederation == 0) || (RTIG_SocketServer == NULL) || (Audit == NULL))
-        throw RTIinternalError();
+    if (myFederation == 0)
+        throw RTIinternalError("");
 }
 
 // ----------------------------------------------------------------------------
@@ -190,4 +189,4 @@ SecurityServer::registerFederate(const char *the_federate,
 
 }
 
-// $Id: SecurityServer.cc,v 3.7 2003/10/27 10:18:56 breholee Exp $
+// $Id: SecurityServer.cc,v 3.9 2005/04/30 17:32:27 breholee Exp $
