@@ -169,7 +169,7 @@ typedef int YYSTYPE;
 
 
 /* Line 214 of yacc.c.  */
-#line 173 "syntax.cc"
+#line 173 "y.tab.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -1274,7 +1274,7 @@ yyreduce:
     }
 
 /* Line 1010 of yacc.c.  */
-#line 1278 "syntax.cc"
+#line 1278 "y.tab.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
